@@ -29,13 +29,43 @@ enable_if2< is_arma_type<T1>::value, const eOp<T1, eop_neg> >::result
 operator-
 (const T1& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOp<T1,eop_neg>(X);
   }
 
 
 
+// //! unary -
+// template<typename T1>
+// arma_inline
+// typename
+// enable_if2< (is_arma_type<T1>::value && is_signed<typename T1::elem_type>::value), const eOp<T1, eop_neg> >::result
+// operator-
+// (const T1& X)
+//   {
+//   arma_debug_sigprint();
+//   
+//   return eOp<T1,eop_neg>(X);
+//   }
+// 
+// 
+// 
+// template<typename T1>
+// arma_inline
+// typename enable_if2< (is_arma_type<T1>::value && (is_signed<typename T1::elem_type>::value == false)), const eOp<T1, eop_scalar_times> >::result
+// operator-
+// (const T1& X)
+//   {
+//   arma_debug_sigprint();
+//   
+//   typedef typename T1::elem_type eT;
+//   
+//   return eOp<T1, eop_scalar_times>(X, eT(-1));
+//   }
+
+
+
 //! Base - scalar
 template<typename T1>
 arma_inline
@@ -47,7 +77,7 @@ operator-
   const typename T1::elem_type k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOp<T1, eop_scalar_minus_post>(X, k);
   }
@@ -65,7 +95,7 @@ operator-
   const T1&                    X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eOp<T1, eop_scalar_minus_pre>(X, k);
   }
@@ -87,7 +117,7 @@ operator-
   const T1&                                  X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return mtOp<typename std::complex<typename T1::pod_type>, T1, op_cx_scalar_minus_pre>('j', X, k);
   }
@@ -109,7 +139,7 @@ operator-
   const std::complex<typename T1::pod_type>& k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return mtOp<typename std::complex<typename T1::pod_type>, T1, op_cx_scalar_minus_post>('j', X, k);
   }
@@ -131,7 +161,7 @@ operator-
   const T2& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return eGlue<T1, T2, eglue_minus>(X, Y);
   }
@@ -153,7 +183,7 @@ operator-
   const T2& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT1;
   typedef typename T2::elem_type eT2;
@@ -179,7 +209,7 @@ enable_if2
 operator-
 (const T1& X)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -203,7 +233,7 @@ operator-
   const T2& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return SpGlue<T1,T2,spglue_minus>(X,Y);
   }
@@ -225,21 +255,28 @@ operator-
   const T2& y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
   
   const SpProxy<T1> pa(x);
   
-  Mat<typename T1::elem_type> result(-y);
+  const quasi_unwrap<T2> UB(y);
+  const Mat<eT>& B     = UB.M;
   
-  arma_debug_assert_same_size( pa.get_n_rows(), pa.get_n_cols(), result.n_rows, result.n_cols, "subtraction" );
+  Mat<eT> result = -B;
+  
+  arma_conform_assert_same_size( pa.get_n_rows(), pa.get_n_cols(), result.n_rows, result.n_cols, "subtraction" );
   
   typename SpProxy<T1>::const_iterator_type it     = pa.begin();
   typename SpProxy<T1>::const_iterator_type it_end = pa.end();
   
-  while(it != it_end)
+  for(; it != it_end; ++it)
     {
-    result.at(it.row(), it.col()) += (*it);
-    ++it;
+    const uword r = it.row();
+    const uword c = it.col();
+    
+    result.at(r, c) = (*it) - B.at(r,c);
     }
   
   return result;
@@ -262,13 +299,13 @@ operator-
   const T2& y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<typename T1::elem_type> result(x);
   
   const SpProxy<T2> pb(y);
   
-  arma_debug_assert_same_size( result.n_rows, result.n_cols, pb.get_n_rows(), pb.get_n_cols(), "subtraction" );
+  arma_conform_assert_same_size( result.n_rows, result.n_cols, pb.get_n_rows(), pb.get_n_cols(), "subtraction" );
   
   typename SpProxy<T2>::const_iterator_type it     = pb.begin();
   typename SpProxy<T2>::const_iterator_type it_end = pb.end();
@@ -299,7 +336,7 @@ operator-
   const T2& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT1;
   typedef typename T2::elem_type eT2;
@@ -328,7 +365,7 @@ operator-
   const T2& y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result > out;
   
@@ -354,7 +391,7 @@ operator-
   const T2& y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result > out;
   
@@ -376,7 +413,7 @@ operator-
   const typename T1::elem_type k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return SpToDOp<T1, op_sp_minus_post>(X, k);
   }
@@ -394,7 +431,7 @@ operator-
   const T1&                    X
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return SpToDOp<T1, op_sp_minus_pre>(X, k);
   }
@@ -419,7 +456,7 @@ operator-
   const typename T1::elem_type k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const typename T1::elem_type aux = (is_same_type<op_type, op_sp_plus>::value) ? -x.aux : x.aux;
 
@@ -446,7 +483,7 @@ operator-
   const SpToDOp<T1, op_type>&  x
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const typename T1::elem_type aux = (is_same_type<op_type, op_sp_plus>::value) ? -x.aux : x.aux;
 
@@ -472,7 +509,7 @@ operator-
   const typename T1::elem_type k
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return SpToDOp<T1, op_sp_minus_pre>(x.m, x.aux - k);
   }
@@ -496,7 +533,7 @@ operator-
   const SpToDOp<T1, op_type>&  x
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return SpToDOp<T1, op_sp_plus>(x.m, k - x.aux);
   }
@@ -512,7 +549,7 @@ operator-
   const Base<typename parent::elem_type,T2>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_each1_aux::operator_minus(X, Y.get_ref());
   }
@@ -528,7 +565,7 @@ operator-
   const subview_each1<parent,mode>&          Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_each1_aux::operator_minus(X.get_ref(), Y);
   }
@@ -544,7 +581,7 @@ operator-
   const Base<typename parent::elem_type,T2>& Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_each2_aux::operator_minus(X, Y.get_ref());
   }
@@ -560,7 +597,7 @@ operator-
   const subview_each2<parent,mode,TB>&       Y
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   return subview_each2_aux::operator_minus(X.get_ref(), Y);
   }
