@@ -24,7 +24,7 @@ template<typename eT, typename T1, typename T2>
 inline
 subview_elem2<eT,T1,T2>::~subview_elem2()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -44,7 +44,7 @@ subview_elem2<eT,T1,T2>::subview_elem2
   , all_rows (in_all_rows)
   , all_cols (in_all_cols)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   }
 
 
@@ -55,7 +55,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::inplace_op(const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
@@ -70,7 +70,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
     const umat& ri = tmp1.M;
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( ((ri.is_vec() == false) && (ri.is_empty() == false)) || ((ci.is_vec() == false) && (ci.is_empty() == false)) ),
       "Mat::elem(): given object must be a vector"
@@ -86,13 +86,13 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
       for(uword ri_count=0; ri_count < ri_n_elem; ++ri_count)
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
         
         if(is_same_type<op_type, op_internal_equ  >::yes) { m_local.at(row,col)  = val; }
         if(is_same_type<op_type, op_internal_plus >::yes) { m_local.at(row,col) += val; }
@@ -109,7 +109,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
     
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ci.is_vec() == false) && (ci.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -122,7 +122,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
       eT* colptr = m_local.colptr(col);
       
@@ -140,7 +140,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
     
     const umat& ri = tmp1.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ri.is_vec() == false) && (ri.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -155,7 +155,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const eT val)
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
       
         if(is_same_type<op_type, op_internal_equ  >::yes) { m_local.at(row,col)  = val; }
         if(is_same_type<op_type, op_internal_plus >::yes) { m_local.at(row,col) += val; }
@@ -175,7 +175,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(m);
   
@@ -193,7 +193,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     const umat& ri = tmp1.M;
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( ((ri.is_vec() == false) && (ri.is_empty() == false)) || ((ci.is_vec() == false) && (ci.is_empty() == false)) ),
       "Mat::elem(): given object must be a vector"
@@ -205,19 +205,19 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     const uword* ci_mem    = ci.memptr();
     const uword  ci_n_elem = ci.n_elem;
     
-    arma_debug_assert_same_size( ri_n_elem, ci_n_elem, X.n_rows, X.n_cols, "Mat::elem()" );
+    arma_conform_assert_same_size( ri_n_elem, ci_n_elem, X.n_rows, X.n_cols, "Mat::elem()" );
     
     for(uword ci_count=0; ci_count < ci_n_elem; ++ci_count)
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
       for(uword ri_count=0; ri_count < ri_n_elem; ++ri_count)
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
         
         if(is_same_type<op_type, op_internal_equ  >::yes) { m_local.at(row,col)  = X.at(ri_count, ci_count); }
         if(is_same_type<op_type, op_internal_plus >::yes) { m_local.at(row,col) += X.at(ri_count, ci_count); }
@@ -234,7 +234,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ci.is_vec() == false) && (ci.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -243,13 +243,13 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     const uword* ci_mem    = ci.memptr();
     const uword  ci_n_elem = ci.n_elem;
     
-    arma_debug_assert_same_size( m_n_rows, ci_n_elem, X.n_rows, X.n_cols, "Mat::elem()" );
+    arma_conform_assert_same_size( m_n_rows, ci_n_elem, X.n_rows, X.n_cols, "Mat::elem()" );
     
     for(uword ci_count=0; ci_count < ci_n_elem; ++ci_count)
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
             eT* m_colptr = m_local.colptr(col);
       const eT* X_colptr = X.colptr(ci_count);
@@ -268,7 +268,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     
     const umat& ri = tmp1.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ri.is_vec() == false) && (ri.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -277,7 +277,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
     const uword* ri_mem    = ri.memptr();
     const uword  ri_n_elem = ri.n_elem;
     
-    arma_debug_assert_same_size( ri_n_elem, m_n_cols, X.n_rows, X.n_cols, "Mat::elem()" );
+    arma_conform_assert_same_size( ri_n_elem, m_n_cols, X.n_rows, X.n_cols, "Mat::elem()" );
     
     for(uword col=0; col < m_n_cols; ++col)
       {
@@ -285,7 +285,7 @@ subview_elem2<eT,T1,T2>::inplace_op(const Base<eT,expr>& x)
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
       
         if(is_same_type<op_type, op_internal_equ  >::yes) { m_local.at(row,col)  = X.at(ri_count, col); }
         if(is_same_type<op_type, op_internal_plus >::yes) { m_local.at(row,col) += X.at(ri_count, col); }
@@ -309,7 +309,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::replace(const eT old_val, const eT new_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT> tmp(*this);
   
@@ -325,7 +325,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::clean(const pod_type threshold)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT> tmp(*this);
   
@@ -341,7 +341,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::clamp(const eT min_val, const eT max_val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT> tmp(*this);
   
@@ -357,7 +357,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::fill(const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(val);
   }
@@ -369,7 +369,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::zeros()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(eT(0));
   }
@@ -381,7 +381,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::ones()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(eT(1));
   }
@@ -393,7 +393,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator+= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(val);
   }
@@ -405,7 +405,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator-= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(val);
   }
@@ -417,7 +417,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator*= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(val);
   }
@@ -429,7 +429,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator/= (const eT val)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(val);
   }
@@ -447,7 +447,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator_equ(const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(x);
   }
@@ -461,7 +461,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator= (const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator_equ(x);
   }
@@ -474,7 +474,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator= (const subview_elem2<eT,T1,T2>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   (*this).operator_equ(x);
   }
@@ -487,7 +487,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator+= (const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(x);
   }
@@ -500,7 +500,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator-= (const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(x);
   }
@@ -513,7 +513,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator%= (const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(x);
   }
@@ -526,7 +526,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator/= (const subview_elem2<eT,T3,T4>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(x);
   }
@@ -539,7 +539,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator= (const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_equ>(x);
   }
@@ -552,7 +552,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator+= (const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_plus>(x);
   }
@@ -565,7 +565,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator-= (const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_minus>(x);
   }
@@ -578,7 +578,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator%= (const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_schur>(x);
   }
@@ -591,7 +591,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator/= (const Base<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   inplace_op<op_internal_div>(x);
   }
@@ -609,7 +609,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator= (const SpBase<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(x);
   
@@ -624,7 +624,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator+= (const SpBase<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(x);
   
@@ -639,7 +639,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator-= (const SpBase<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(x);
   
@@ -654,7 +654,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator%= (const SpBase<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(x);
   
@@ -669,7 +669,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::operator/= (const SpBase<eT,expr>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(x);
   
@@ -688,7 +688,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,T2>& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<eT>& m_local = const_cast< Mat<eT>& >(in.m);
   
@@ -697,9 +697,9 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
   
   const bool alias = (&actual_out == &m_local);
   
-  if(alias)  { arma_extra_debug_print("subview_elem2::extract(): aliasing detected"); }
+  if(alias)  { arma_debug_print("subview_elem2::extract(): aliasing detected"); }
   
-  Mat<eT>* tmp_out = alias ? new Mat<eT>() : 0;
+  Mat<eT>* tmp_out = alias ? new Mat<eT>() : nullptr;
   Mat<eT>& out     = alias ? *tmp_out      : actual_out;
   
   if( (in.all_rows == false) && (in.all_cols == false) )
@@ -710,7 +710,7 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
     const umat& ri = tmp1.M;
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( ((ri.is_vec() == false) && (ri.is_empty() == false)) || ((ci.is_vec() == false) && (ci.is_empty() == false)) ),
       "Mat::elem(): given object must be a vector"
@@ -731,13 +731,13 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
       for(uword ri_count=0; ri_count < ri_n_elem; ++ri_count)
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
         
         out_mem[out_count] = m_local.at(row,col);
         ++out_count;
@@ -751,7 +751,7 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
     
     const umat& ci = tmp2.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ci.is_vec() == false) && (ci.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -766,7 +766,7 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
       {
       const uword col = ci_mem[ci_count];
       
-      arma_debug_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
+      arma_conform_check_bounds( (col >= m_n_cols), "Mat::elem(): index out of bounds" );
       
       arrayops::copy( out.colptr(ci_count), m_local.colptr(col), m_n_rows );
       }
@@ -778,7 +778,7 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
     
     const umat& ri = tmp1.M;
     
-    arma_debug_check
+    arma_conform_check
       (
       ( (ri.is_vec() == false) && (ri.is_empty() == false) ),
       "Mat::elem(): given object must be a vector"
@@ -795,7 +795,7 @@ subview_elem2<eT,T1,T2>::extract(Mat<eT>& actual_out, const subview_elem2<eT,T1,
         {
         const uword row = ri_mem[ri_count];
         
-        arma_debug_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
+        arma_conform_check_bounds( (row >= m_n_rows), "Mat::elem(): index out of bounds" );
         
         out.at(ri_count,col) = m_local.at(row,col);
         }
@@ -819,7 +819,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::plus_inplace(Mat<eT>& out, const subview_elem2& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(in);
   
@@ -833,7 +833,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::minus_inplace(Mat<eT>& out, const subview_elem2& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(in);
   
@@ -847,7 +847,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::schur_inplace(Mat<eT>& out, const subview_elem2& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(in);
   
@@ -861,7 +861,7 @@ inline
 void
 subview_elem2<eT,T1,T2>::div_inplace(Mat<eT>& out, const subview_elem2& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const Mat<eT> tmp(in);
   
